pub struct NodeDivergence {
pub common_prefix: Vec<String>,
pub tail_a: Vec<NodeStep>,
pub tail_b: Vec<NodeStep>,
}Expand description
The divergence point between two node traversal paths.
Fields
common_prefix: Vec<String>Node IDs that both paths share before the first mismatch.
tail_a: Vec<NodeStep>Remaining steps only in path A after the divergence point.
tail_b: Vec<NodeStep>Remaining steps only in path B after the divergence point.