pub struct GateRuleSet {
pub thresholds: EvalThresholds,
pub rules: Vec<GateRule>,
}Expand description
A set of gate rules plus the thresholds they reference.
Fields
thresholds: EvalThresholdsrules: Vec<GateRule>Implementations
Sourceimpl GateRuleSet
impl GateRuleSet
Sourcepub fn standard() -> Self
pub fn standard() -> Self
Create a rule set with default thresholds and the standard rules
(MinPassRate + MaxRegression).
Sourcepub fn with_thresholds(self, thresholds: EvalThresholds) -> Self
pub fn with_thresholds(self, thresholds: EvalThresholds) -> Self
Override thresholds.