pub struct CompactionPolicy {
pub max_age_days: Option<u64>,
pub max_entries_per_key: Option<usize>,
pub strategy: CompactionStrategy,
}Expand description
Policy for memory retention and compaction.
Fields
max_age_days: Option<u64>max_entries_per_key: Option<usize>strategy: CompactionStrategyImplementations
Sourceimpl CompactionPolicy
impl CompactionPolicy
pub fn delete_older_than(days: u64) -> Self
pub fn keep_recent(per_key: usize) -> Self
Sourcepub fn compact(&self, entries: &[MemoryEntry]) -> CompactionResult
pub fn compact(&self, entries: &[MemoryEntry]) -> CompactionResult
Apply compaction to a list of memory entries, returning retained entries and the count of compacted entries.