pub struct GraphRunRecorder { /* private fields */ }Expand description
Adapter that records graph lifecycle Events into a RunLedger.
Usage:
- Call
GraphRunRecorder::startto create a new run. - Call
GraphRunRecorder::recordfor each domain event. - Call
GraphRunRecorder::finish_okorGraphRunRecorder::finish_errto finalize.
Implementations
Sourceimpl GraphRunRecorder
impl GraphRunRecorder
Sourcepub async fn start(
ledger: Arc<dyn RunLedger>,
spec_digest: &ContentDigest,
metadata: RunMetadata,
) -> StorageResult<Self>
pub async fn start( ledger: Arc<dyn RunLedger>, spec_digest: &ContentDigest, metadata: RunMetadata, ) -> StorageResult<Self>
Start a new run in the ledger, returning a recorder bound to that run.
Sourcepub async fn record(&self, event: &Event) -> StorageResult<()>
pub async fn record(&self, event: &Event) -> StorageResult<()>
Record a single domain event into the ledger.
Sourcepub async fn finish_ok(self, summary: RunSummary) -> StorageResult<()>
pub async fn finish_ok(self, summary: RunSummary) -> StorageResult<()>
Finalize the run as completed.
Sourcepub async fn finish_err(self, summary: RunSummary) -> StorageResult<()>
pub async fn finish_err(self, summary: RunSummary) -> StorageResult<()>
Finalize the run as failed.