pub struct CircuitBreaker { /* private fields */ }Expand description
Atomic circuit breaker that opens after N consecutive failures.
Thread-safe via AtomicU32. Resets on success.
Implementations
Sourceimpl CircuitBreaker
impl CircuitBreaker
Sourcepub fn new(threshold: u32) -> Self
pub fn new(threshold: u32) -> Self
Create a new circuit breaker with the given failure threshold.
Sourcepub fn is_open(&self) -> bool
pub fn is_open(&self) -> bool
Returns true if the breaker is open (too many consecutive failures).
Sourcepub fn record_failure(&self) -> u32
pub fn record_failure(&self) -> u32
Record a failure. Returns current consecutive failure count.
Sourcepub fn record_success(&self)
pub fn record_success(&self)
Reset on success.
Sourcepub fn failure_count(&self) -> u32
pub fn failure_count(&self) -> u32
Current consecutive failure count.