Skip to main contentModule state_diff
Source - ScopedStateDiff
- The result of diffing two states at scoped JSON pointer paths.
- StateDelta
- A single delta at an RFC 6901 JSON pointer path between two states.
- CHECKPOINT_SAVED_KIND
- Event kind emitted by the oxidizedgraph event adapter when a checkpoint is saved.
- diff_run_states
- Convenience: extract last checkpoint state from two event streams and diff
at the given JSON pointer paths.
- diff_scoped_state
- Diff two JSON values at the given RFC 6901 JSON pointer paths.
- extract_last_checkpoint
- Extract the payload of the last
"CheckpointSaved" event from a run event stream.